diff libpurple/protocols/jabber/iq.c @ 15823:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 6ab1089e2101 e0e4fc6e2cc8
line wrap: on
line diff
--- a/libpurple/protocols/jabber/iq.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/jabber/iq.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,5 +1,5 @@
 /*
  * gaim - Jabber Protocol Plugin
  *
  * Copyright (C) 2003, Nathan Walp <faceprint@faceprint.com>
  *
@@ -191,13 +191,13 @@
 
 		query = xmlnode_get_child(iq->node, "query");
 
-		date = gaim_utf8_strftime("%Y%m%dT%T", now);
+		date = purple_utf8_strftime("%Y%m%dT%T", now);
 		xmlnode_insert_data(xmlnode_new_child(query, "utc"), date, -1);
 
-		date = gaim_utf8_strftime("%Z", now);
+		date = purple_utf8_strftime("%Z", now);
 		xmlnode_insert_data(xmlnode_new_child(query, "tz"), date, -1);
 
-		date = gaim_utf8_strftime("%d %b %Y %T", now);
+		date = purple_utf8_strftime("%d %b %Y %T", now);
 		xmlnode_insert_data(xmlnode_new_child(query, "display"), date, -1);
 
 		jabber_iq_send(iq);
@@ -215,7 +215,7 @@
 
 	if(type && !strcmp(type, "get")) {
 
-		if(!gaim_prefs_get_bool("/plugins/prpl/jabber/hide_os")) {
+		if(!purple_prefs_get_bool("/plugins/prpl/jabber/hide_os")) {
 			struct utsname osinfo;
 
 			uname(&osinfo);
@@ -1,5 +1,5 @@
 /*
- * gaim - Jabber Protocol Plugin
+ * purple - Jabber Protocol Plugin
  *
  * Copyright (C) 2003, Nathan Walp <faceprint@faceprint.com>